# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: imu_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'imu_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11imu_service.proto\x12\x0bimu_service\"\xb0\x02\n\nIMUPayload\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x30\n\raccelerometer\x18\x03 \x03(\x0b\x32\x19.imu_service.SensorValues\x12,\n\tgyroscope\x18\x04 \x03(\x0b\x32\x19.imu_service.SensorValues\x12*\n\x07gravity\x18\x05 \x03(\x0b\x32\x19.imu_service.SensorValues\x12\x35\n\x12total_acceleration\x18\x06 \x03(\x0b\x32\x19.imu_service.SensorValues\x12\x39\n\x0borientation\x18\x07 \x03(\x0b\x32$.imu_service.OrientationSensorValues\"J\n\x12IMUPayloadResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x0e\n\x06status\x18\x03 \x01(\t\"/\n\x0cSensorValues\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01z\x18\x03 \x01(\x01\"s\n\x17OrientationSensorValues\x12\n\n\x02qx\x18\x01 \x01(\x01\x12\n\n\x02qy\x18\x02 \x01(\x01\x12\n\n\x02qz\x18\x03 \x01(\x01\x12\n\n\x02qw\x18\x04 \x01(\x01\x12\x0c\n\x04roll\x18\x05 \x01(\x01\x12\r\n\x05pitch\x18\x06 \x01(\x01\x12\x0b\n\x03yaw\x18\x07 \x01(\x01\"\x14\n\x12HealthCheckRequest\"6\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t2\xaa\x01\n\nIMUService\x12P\n\x0bHealthCheck\x12\x1f.imu_service.HealthCheckRequest\x1a .imu_service.HealthCheckResponse\x12J\n\x0eSendIMUPayload\x12\x17.imu_service.IMUPayload\x1a\x1f.imu_service.IMUPayloadResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'imu_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IMUPAYLOAD']._serialized_start=35
  _globals['_IMUPAYLOAD']._serialized_end=339
  _globals['_IMUPAYLOADRESPONSE']._serialized_start=341
  _globals['_IMUPAYLOADRESPONSE']._serialized_end=415
  _globals['_SENSORVALUES']._serialized_start=417
  _globals['_SENSORVALUES']._serialized_end=464
  _globals['_ORIENTATIONSENSORVALUES']._serialized_start=466
  _globals['_ORIENTATIONSENSORVALUES']._serialized_end=581
  _globals['_HEALTHCHECKREQUEST']._serialized_start=583
  _globals['_HEALTHCHECKREQUEST']._serialized_end=603
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=605
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=659
  _globals['_IMUSERVICE']._serialized_start=662
  _globals['_IMUSERVICE']._serialized_end=832
# @@protoc_insertion_point(module_scope)
