# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: orchestrator_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'orchestrator_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import imu_service_pb2 as imu__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aorchestrator_service.proto\x12\x14orchestrator_service\x1a\x11imu_service.proto\"\x14\n\x12HealthCheckRequest\"%\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\"\x1b\n\x19OrchestratorStatusRequest\"H\n\x1aOrchestratorStatusResponse\x12\x10\n\x08is_ready\x18\x01 \x01(\x08\x12\x18\n\x10\x63urrent_activity\x18\x02 \x01(\t2\xbe\x02\n\x13OrchestratorService\x12\x62\n\x0bHealthCheck\x12(.orchestrator_service.HealthCheckRequest\x1a).orchestrator_service.HealthCheckResponse\x12w\n\x12OrchestratorStatus\x12/.orchestrator_service.OrchestratorStatusRequest\x1a\x30.orchestrator_service.OrchestratorStatusResponse\x12J\n\x0eReceiveIMUData\x12\x17.imu_service.IMUPayload\x1a\x1f.imu_service.IMUPayloadResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'orchestrator_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEALTHCHECKREQUEST']._serialized_start=71
  _globals['_HEALTHCHECKREQUEST']._serialized_end=91
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=93
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=130
  _globals['_ORCHESTRATORSTATUSREQUEST']._serialized_start=132
  _globals['_ORCHESTRATORSTATUSREQUEST']._serialized_end=159
  _globals['_ORCHESTRATORSTATUSRESPONSE']._serialized_start=161
  _globals['_ORCHESTRATORSTATUSRESPONSE']._serialized_end=233
  _globals['_ORCHESTRATORSERVICE']._serialized_start=236
  _globals['_ORCHESTRATORSERVICE']._serialized_end=554
# @@protoc_insertion_point(module_scope)
