# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rfid_service.proto
# Protobuf Python Version: 6.31.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    0,
    '',
    'rfid_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12rfid_service.proto\x12\x0crfid_service\"\x14\n\x12HealthCheckRequest\"6\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"T\n\x0bRFIDPayload\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\"K\n\x13RFIDPayloadResponse\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x0e\n\x06status\x18\x03 \x01(\t2\xb2\x01\n\x0bRFIDService\x12R\n\x0bHealthCheck\x12 .rfid_service.HealthCheckRequest\x1a!.rfid_service.HealthCheckResponse\x12O\n\x0fSendRFIDPayload\x12\x19.rfid_service.RFIDPayload\x1a!.rfid_service.RFIDPayloadResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rfid_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEALTHCHECKREQUEST']._serialized_start=36
  _globals['_HEALTHCHECKREQUEST']._serialized_end=56
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=58
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=112
  _globals['_RFIDPAYLOAD']._serialized_start=114
  _globals['_RFIDPAYLOAD']._serialized_end=198
  _globals['_RFIDPAYLOADRESPONSE']._serialized_start=200
  _globals['_RFIDPAYLOADRESPONSE']._serialized_end=275
  _globals['_RFIDSERVICE']._serialized_start=278
  _globals['_RFIDSERVICE']._serialized_end=456
# @@protoc_insertion_point(module_scope)
